package com.zjsgfa.project.zjsgfa.mapper;

import java.util.List;
import com.zjsgfa.project.zjsgfa.domain.MxfxjgbTsc;

/**
 * 大模型分析-提示词Mapper接口
 * 
 * @author ruoyi
 * @date 2025-12-11
 */
public interface MxfxjgbTscMapper 
{
    /**
     * 查询大模型分析-提示词
     * 
     * @param id 大模型分析-提示词主键
     * @return 大模型分析-提示词
     */
    public MxfxjgbTsc selectMxfxjgbTscById(Long id);

    /**
     * 查询大模型分析-提示词列表
     * 
     * @param mxfxjgbTsc 大模型分析-提示词
     * @return 大模型分析-提示词集合
     */
    public List<MxfxjgbTsc> selectMxfxjgbTscList(MxfxjgbTsc mxfxjgbTsc);

    /**
     * 新增大模型分析-提示词
     * 
     * @param mxfxjgbTsc 大模型分析-提示词
     * @return 结果
     */
    public int insertMxfxjgbTsc(MxfxjgbTsc mxfxjgbTsc);

    /**
     * 修改大模型分析-提示词
     * 
     * @param mxfxjgbTsc 大模型分析-提示词
     * @return 结果
     */
    public int updateMxfxjgbTsc(MxfxjgbTsc mxfxjgbTsc);

    /**
     * 删除大模型分析-提示词
     * 
     * @param id 大模型分析-提示词主键
     * @return 结果
     */
    public int deleteMxfxjgbTscById(Long id);

    /**
     * 批量删除大模型分析-提示词
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMxfxjgbTscByIds(Long[] ids);
}
